@@ -15,19 +15,23 @@ class PureAd(SourceBase):
     meta_video_url: Optional[str] = Field(default=None)
     meta_image_url: Optional[str] = Field(default=None)
     meta_thumbnail_url: Optional[str] = Field(default=None)
-    
+
     exclude_fields = {
         SerializerType.FRONTEND_ASSET_PREVIEW: {"meta_ad_url", "meta_referral_type", "meta_body", "meta_headline", "meta_media_type", "meta_video_url", "meta_image_url", "meta_thumbnail_url"}
     }
 
+    @property
+    def default_category(self) -> str:
+        return "Anuncios Click to WhatsApp (META)"
+
     @property
     def type(self) -> SourceType:
         return SourceType.PURE_AD
-    
+
     def __eq__(self, other: PureAd) -> bool:
         if hasattr(other, "ad_id"):
             return self.ad_id == other.ad_id
         return False
-    
+
     def __hash__(self) -> int:
         return hash(self.ad_id)
\ No newline at end of file
