@@ -11,11 +11,13 @@ class ChattyContentContact(BaseModel):
     emails: Optional[List[Dict[str, Any]]] = Field(default=None)
     org: Optional[Dict[str, Any]] = Field(default=None)
     urls: Optional[List[Dict[str, Any]]] = Field(default=None)
-    
+
     def model_dump(self) -> Dict[str, Any]:
         data = super().model_dump(exclude_none=True)
         return data
-        
+
 class ChattyContentContacts(BaseModel):
     contacts: List[ChattyContentContact]
-    
\ No newline at end of file
+
+    def get_body_or_caption(self) -> str:
+        return f"El usuario envió un contacto"
